==> org.eclipse.egit.gitflow.ui.source_5.3.0.201903130848-r.jar: org/eclipse/egit/gitflow/ui/internal/actions/StartDialog.java <==
/*******************************************************************************
 * Copyright (C) 2018, Max Hohenegger <eclipse@hohenegger.eu>
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *******************************************************************************/
package org.eclipse.egit.gitflow.ui.internal.actions;

import org.eclipse.egit.gitflow.ui.internal.UIText;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.IInputValidator;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;

class StartDialog extends InputDialog {

	private Button startButton;

	StartDialog(Shell parentShell, String dialogTitle,
			String dialogMessage, String initialValue,
			IInputValidator validator) {
		super(parentShell, dialogTitle, dialogMessage, initialValue, validator);
	}

	@Override
	protected void createButtonsForButtonBar(Composite parent) {
		startButton = createButton(parent, IDialogConstants.OK_ID,
				UIText.StartDialog_ButtonOK, true);
		createButton(parent, IDialogConstants.CANCEL_ID,
				IDialogConstants.CANCEL_LABEL, false);

		getText().setFocus();
		if (getValue() != null) {
			getText().setText(getValue());
			getText().selectAll();
		}
	}

	@Override
	protected Button getOkButton() {
		return startButton;
	}
}

==> org.eclipse.egit.gitflow.ui.source_5.9.0.202009080501-r.jar: org/eclipse/egit/gitflow/ui/internal/actions/StartDialog.java <==
/*******************************************************************************
 * Copyright (C) 2019, Max Hohenegger <eclipse@hohenegger.eu>
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *******************************************************************************/
package org.eclipse.egit.gitflow.ui.internal.actions;

import org.eclipse.egit.gitflow.ui.internal.UIText;
import org.eclipse.egit.ui.internal.components.BranchNameNormalizer;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.IInputValidator;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;

class StartDialog extends InputDialog {

	private Button startButton;

	StartDialog(Shell parentShell, String dialogTitle,
			String dialogMessage, String initialValue,
			IInputValidator validator) {
		super(parentShell, dialogTitle, dialogMessage, initialValue, validator);
	}

	@Override
	protected void createButtonsForButtonBar(Composite parent) {
		startButton = createButton(parent, IDialogConstants.OK_ID,
				UIText.StartDialog_ButtonOK, true);
		createButton(parent, IDialogConstants.CANCEL_ID,
				IDialogConstants.CANCEL_LABEL, false);

		getText().setFocus();
		if (getValue() != null) {
			getText().setText(getValue());
			getText().selectAll();
		}
	}

	@Override
	protected Control createDialogArea(Composite parent) {
		Control result = super.createDialogArea(parent);
		BranchNameNormalizer normalizer = new BranchNameNormalizer(getText());
		normalizer.setVisible(false);
		return result;
	}

	@Override
	protected Button getOkButton() {
		return startButton;
	}
}
